import Layout from '@/layout'

const businessRouter = {
  path: '/business',
  component: Layout,
  name: 'Business',
  meta: { title: '业务中心', icon: 'el-icon-s-shop' },
  redirect: '/business/outlet/list',
  children: [
    {
      path: 'outlet',
      component: () => import('@/views/business/outlet/index'),
      name: 'BusinessOutlet',
      meta: { title: '门店管理', icon: 'el-icon-s-shop' },
      redirect: '/business/outlet/list',
      children: [
        {
          path: 'list',
          component: () => import('@/views/business/outlet/list/index'),
          name: 'BusinessOutletList',
          meta: { title: '门店列表' }
        }
      ]
    },
    {
      path: 'place',
      component: () => import('@/views/business/place/index'),
      name: 'BusinessPlace',
      meta: { title: '订座管理', icon: 'el-icon-place' },
      redirect: '/business/place/reserve',
      children: [
        {
          path: 'reserve',
          component: () => import('@/views/business/place/reserve/index'),
          name: 'BusinessPlaceReserve',
          meta: { title: '预订' }
        },
        {
          path: 'set',
          component: () => import('@/views/business/place/set/index'),
          name: 'BusinessPlaceSet',
          meta: { title: '未来7天排座' }
        },
        {
          path: 'list',
          component: () => import('@/views/business/place/list/index'),
          name: 'BusinessPlaceList',
          meta: { title: '座位模板' }
        }
      ]
    },
    {
      path: 'sms',
      component: () => import('@/views/business/sms/index'),
      name: 'BusinessSMS',
      meta: { title: '演出管理', icon: 'el-icon-headset' },
      redirect: '/business/sms/plan',
      children: [
        {
          path: 'pickASong',
          component: () => import('@/views/business/sms/pickASong/index'),
          name: 'BusinessSMSPickASong',
          meta: { title: '点歌记录' }
        },
        {
          path: 'reward',
          component: () => import('@/views/business/sms/reward/index'),
          name: 'BusinessSMSReward',
          meta: { title: '赞赏记录' }
        },
        {
          path: 'plan',
          component: () => import('@/views/business/sms/plan/index'),
          name: 'BusinessSMSPlan',
          meta: { title: '演出安排' }
        },
        {
          path: 'musicLib',
          component: () => import('@/views/business/sms/musicLib/index'),
          name: 'BusinessSMSMusicLib',
          meta: { title: '曲库管理' }
        },
        {
          path: 'playList',
          component: () => import('@/views/business/sms/playList/index'),
          name: 'BusinessSMSPlayList',
          meta: { title: '艺人曲库' },
          hidden: true
        }
      ]
    },
    {
      path: 'oms',
      component: () => import('@/views/business/oms/index'),
      name: 'BusinessOMS',
      meta: { title: '点单管理', icon: 'el-icon-s-order' },
      redirect: '/business/oms/order',
      children: [
        {
          path: 'order',
          component: () => import('@/views/business/oms/list/index'),
          name: 'BusinessOMSOrder',
          meta: { title: '点单列表' }
        },
        {
          path: 'detail',
          component: () => import('@/views/business/oms/detail/index'),
          name: 'BusinessOMSDetail',
          meta: { title: '点单详情' },
          hidden: true
        }
      ]
    },
    {
      path: 'pms',
      component: () => import('@/views/business/pms/index'),
      name: 'BusinessPMS',
      meta: { title: '商品管理', icon: 'el-icon-goods' },
      redirect: '/business/pms/goods',
      children: [
        {
          path: 'category',
          component: () => import('@/views/business/pms/category/index'),
          name: 'BusinessPMSCategory',
          meta: { title: '商品分类' }
        },
        {
          path: 'goods',
          component: () => import('@/views/business/pms/goods/index'),
          name: 'BusinessPMSGoods',
          meta: { title: '商品列表' }
        },
        {
          path: 'goodsAttr',
          component: () => import('@/views/business/pms/goodsAttr/index'),
          name: 'BusinessPMSGoodsAttr',
          meta: { title: '商品附加' }
        }
      ]
    }
  ]
}

export default businessRouter
